==> kubernetes-model-1.0.6-sources.jar: io/fabric8/kubernetes/api/model/NodeConditionFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class NodeConditionFluent<T extends NodeConditionFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String lastHeartbeatTime;     String lastTransitionTime;     String message;     String reason;     String status;     String type;     Map<String, Object> additionalProperties = new HashMap();

    public String getLastHeartbeatTime(){
    return this.lastHeartbeatTime;
    }
    public T withLastHeartbeatTime( String lastHeartbeatTime){
    this.lastHeartbeatTime=lastHeartbeatTime; return (T) this;
    }
    public String getLastTransitionTime(){
    return this.lastTransitionTime;
    }
    public T withLastTransitionTime( String lastTransitionTime){
    this.lastTransitionTime=lastTransitionTime; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public String getStatus(){
    return this.status;
    }
    public T withStatus( String status){
    this.status=status; return (T) this;
    }
    public String getType(){
    return this.type;
    }
    public T withType( String type){
    this.type=type; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }



}

==> kubernetes-model-1.0.7-sources.jar: io/fabric8/kubernetes/api/model/NodeConditionFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class NodeConditionFluent<T extends NodeConditionFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String lastHeartbeatTime;     String lastTransitionTime;     String message;     String reason;     String status;     String type;     Map<String, Object> additionalProperties = new HashMap();

    public String getLastHeartbeatTime(){
    return this.lastHeartbeatTime;
    }
    public T withLastHeartbeatTime( String lastHeartbeatTime){
    this.lastHeartbeatTime=lastHeartbeatTime; return (T) this;
    }
    public String getLastTransitionTime(){
    return this.lastTransitionTime;
    }
    public T withLastTransitionTime( String lastTransitionTime){
    this.lastTransitionTime=lastTransitionTime; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public String getStatus(){
    return this.status;
    }
    public T withStatus( String status){
    this.status=status; return (T) this;
    }
    public String getType(){
    return this.type;
    }
    public T withType( String type){
    this.type=type; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
NodeConditionFluent that = (NodeConditionFluent) o;
if (lastHeartbeatTime != null ? !lastHeartbeatTime.equals(that.lastHeartbeatTime) :that.lastHeartbeatTime != null) return false;
if (lastTransitionTime != null ? !lastTransitionTime.equals(that.lastTransitionTime) :that.lastTransitionTime != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
if (status != null ? !status.equals(that.status) :that.status != null) return false;
if (type != null ? !type.equals(that.type) :that.type != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
